From 94efb59833a3f9f79cfacc26c165ee7165f58b45 Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter_e@gmx.net>
Date: Tue, 10 Jul 2018 16:07:10 +0200
Subject: [PATCH 5/5] Remove obsolete netbsd dynloader code

dlopen() has been documented since NetBSD 1.1 (1995).
---
 src/backend/port/dynloader/netbsd.c | 103 +---------------------------
 src/backend/port/dynloader/netbsd.h |  29 ++------
 2 files changed, 6 insertions(+), 126 deletions(-)

diff --git a/src/backend/port/dynloader/netbsd.c b/src/backend/port/dynloader/netbsd.c
index 7b8d90caa7..8f7f56864d 100644
--- a/src/backend/port/dynloader/netbsd.c
+++ b/src/backend/port/dynloader/netbsd.c
@@ -1,106 +1,7 @@
 /*
- * Portions Copyright (c) 1996-2018, PostgreSQL Global Development Group
- * Portions Copyright (c) 1990 The Regents of the University of California.
- * All rights reserved.
- *
  * src/backend/port/dynloader/netbsd.c
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *	  notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *	  notice, this list of conditions and the following disclaimer in the
- *	  documentation and/or other materials provided with the distribution.
- * 3. Neither the name of the University nor the names of its contributors
- *	  may be used to endorse or promote products derived from this software
- *	  without specific prior written permission.
+ * Dummy file used for nothing at this point
  *
- * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * see netbsd.h
  */
-
-#if defined(LIBC_SCCS) && !defined(lint)
-static char sccsid[] = "@(#)dl.c	5.4 (Berkeley) 2/23/91";
-#endif							/* LIBC_SCCS and not lint */
-
-#include "postgres.h"
-
-#include <nlist.h>
-#include <link.h>
-#include <dlfcn.h>
-
-#include "dynloader.h"
-
-static char error_message[BUFSIZ];
-
-char *
-BSD44_derived_dlerror(void)
-{
-	static char ret[BUFSIZ];
-
-	strcpy(ret, error_message);
-	error_message[0] = 0;
-	return (ret[0] == 0) ? NULL : ret;
-}
-
-void *
-BSD44_derived_dlopen(const char *file, int num)
-{
-#if !defined(HAVE_DLOPEN)
-	snprintf(error_message, sizeof(error_message),
-			 "dlopen (%s) not supported", file);
-	return NULL;
-#else
-	void	   *vp;
-
-	if ((vp = dlopen((char *) file, num)) == NULL)
-		snprintf(error_message, sizeof(error_message),
-				 "dlopen (%s) failed: %s", file, dlerror());
-	return vp;
-#endif
-}
-
-void *
-BSD44_derived_dlsym(void *handle, const char *name)
-{
-#if !defined(HAVE_DLOPEN)
-	snprintf(error_message, sizeof(error_message),
-			 "dlsym (%s) failed", name);
-	return NULL;
-#else
-	void	   *vp;
-
-#ifndef __ELF__
-	char		buf[BUFSIZ];
-
-	if (*name != '_')
-	{
-		snprintf(buf, sizeof(buf), "_%s", name);
-		name = buf;
-	}
-#endif							/* !__ELF__ */
-	if ((vp = dlsym(handle, (char *) name)) == NULL)
-		snprintf(error_message, sizeof(error_message),
-				 "dlsym (%s) failed", name);
-	return vp;
-#endif
-}
-
-void
-BSD44_derived_dlclose(void *handle)
-{
-#if defined(HAVE_DLOPEN)
-	dlclose(handle);
-#endif
-}
diff --git a/src/backend/port/dynloader/netbsd.h b/src/backend/port/dynloader/netbsd.h
index 823574abf0..f3c38eb98a 100644
--- a/src/backend/port/dynloader/netbsd.h
+++ b/src/backend/port/dynloader/netbsd.h
@@ -3,7 +3,6 @@
  * netbsd.h
  *	  port-specific prototypes for NetBSD
  *
- *
  * Portions Copyright (c) 1996-2018, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
@@ -14,25 +13,10 @@
 #ifndef PORT_PROTOS_H
 #define PORT_PROTOS_H
 
-#include <nlist.h>
-#include <link.h>
 #include <dlfcn.h>
 
 #include "utils/dynamic_loader.h"	/* pgrminclude ignore */
 
-/*
- * Dynamic Loader on NetBSD 1.0.
- *
- * this dynamic loader uses the system dynamic loading interface for shared
- * libraries (ie. dlopen/dlsym/dlclose). The user must specify a shared
- * library as the file to be dynamically loaded.
- *
- * agc - I know this is all a bit crufty, but it does work, is fairly
- * portable, and works (the stipulation that the d.l. function must
- * begin with an underscore is fairly tricky, and some versions of
- * NetBSD (like 1.0, and 1.0A pre June 1995) have no dlerror.)
- */
-
 /*
  * In some older systems, the RTLD_NOW flag isn't defined and the mode
  * argument to dlopen must always be 1.  The RTLD_GLOBAL flag is wanted
@@ -46,14 +30,9 @@
 #define RTLD_GLOBAL 0
 #endif
 
-#define		   pg_dlopen(f)    BSD44_derived_dlopen((f), RTLD_NOW | RTLD_GLOBAL)
-#define		   pg_dlsym		   BSD44_derived_dlsym
-#define		   pg_dlclose	   BSD44_derived_dlclose
-#define		   pg_dlerror	   BSD44_derived_dlerror
-
-char	   *BSD44_derived_dlerror(void);
-void	   *BSD44_derived_dlopen(const char *filename, int num);
-void	   *BSD44_derived_dlsym(void *handle, const char *name);
-void		BSD44_derived_dlclose(void *handle);
+#define pg_dlopen(f)	dlopen((f), RTLD_NOW | RTLD_GLOBAL)
+#define pg_dlsym		dlsym
+#define pg_dlclose		dlclose
+#define pg_dlerror		dlerror
 
 #endif							/* PORT_PROTOS_H */
-- 
2.18.0

